.. _glossary:

========
Glossary
========

.. glossary::

    Configuration
        The configuration is a set of parameters that will define the level for each
        noise type in a ConfigTree object.

    Forms
        Forms are analogous to a dataset that will be noised and returned to the
        user with errors in the data at a level provided by the configuration.
        The noised datasets will be output in the format of different census and
        tax forms.

    Noise functions
        Functions that will be applied to forms at a row or column level to apply
        errors or mistakes in the data to replicate realistic challenges in personal
        record linkage.